The following people have contributed to the development of
`pyseobnr`, either directly or indirectly, listed in alphabetical
order:

``` bash
Hector Estelles, Deyan Mihaylov, Lorenzo Pompili, Antoni Ramos-Buades, Serguei Ossokine
```

If your name is not here, please contact the people listed to remedy
the situation.
